@@ -1,5 +1,6 @@
 var NAVTREEINDEX7 =
 {
+"structpw__core__methods.html#a7e77a9289cd4ba827a7082109d207459":[10,0,29,1],
 "structpw__core__methods.html#a96ae294d1a899b90a6a8d3458a300fe2":[10,0,29,4],
 "structpw__core__methods.html#aa5ee0b92d1e85c741adcaa93a04622fa":[10,0,29,3],
 "structpw__core__methods.html#ab64487c2ddac4c7d315cc54a4d5b7176":[10,0,29,7],
@@ -248,6 +249,5 @@ var NAVTREEINDEX7 =
 "structpw__port__methods.html#a3c19aedb668ea1a71bc12f89b106d94a":[10,0,85,2],
 "structpw__port__methods.html#a77b4f3e654eb54c6066faa61fa478186":[10,0,85,3],
 "structpw__port__methods.html#a902dc57cb5eaae752960a0667ff10ab8":[10,0,85,1],
-"structpw__port__methods.html#adbe08858422d830443b9f111cd6d44bd":[10,0,85,0],
-"structpw__properties.html":[10,0,86]
+"structpw__port__methods.html#adbe08858422d830443b9f111cd6d44bd":[10,0,85,0]
 };
